==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Step.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { StepStepType_$type } from "./StepStepType";
import { StepTitlePosition_$type } from "./StepTitlePosition";
import { StepOrientation_$type } from "./StepOrientation";
/**
 * @hidden
 */
var Step = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Step, _super);
    function Step() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.p = null;
        return _this;
    }
    Object.defineProperty(Step.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "nativeElement", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.d.n = this.p;
        },
        enumerable: false,
        configurable: true
    });
    Step.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Step.prototype, "j", {
        get: function () {
            var ret_ = this.e.m("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "f", {
        get: function () {
            var ret_ = this.e.m("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "l", {
        get: function () {
            var ret_ = this.e.m("optional");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("optional", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "i", {
        get: function () {
            var ret_ = this.e.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "g", {
        get: function () {
            var ret_ = this.e.m("complete");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("complete", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "m", {
        get: function () {
            var ret_ = this.e.m("previousComplete");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("previousComplete", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "b", {
        get: function () {
            var ret_ = this.e.m("stepType");
            ret_ = enumGetBox(StepStepType_$type, EnumUtil.getEnumValue(StepStepType_$type, this.e.f(StepStepType_$type, ret_)));
            return EnumUtil.getEnumValue(StepStepType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepStepType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("stepType", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "c", {
        get: function () {
            var ret_ = this.e.m("titlePosition");
            ret_ = enumGetBox(StepTitlePosition_$type, EnumUtil.getEnumValue(StepTitlePosition_$type, this.e.f(StepTitlePosition_$type, ret_)));
            return EnumUtil.getEnumValue(StepTitlePosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepTitlePosition_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("titlePosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "a", {
        get: function () {
            var ret_ = this.e.m("orientation");
            ret_ = enumGetBox(StepOrientation_$type, EnumUtil.getEnumValue(StepOrientation_$type, this.e.f(StepOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(StepOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepOrientation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("orientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "o", {
        get: function () {
            var ret_ = this.e.m("index");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("index", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "h", {
        get: function () {
            var ret_ = this.e.m("contentTop");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("contentTop", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "k", {
        get: function () {
            var ret_ = this.e.m("linearDisabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("linearDisabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "n", {
        get: function () {
            var ret_ = this.e.m("visited");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("visited", value_);
        },
        enumerable: false,
        configurable: true
    });
    Step.$t = markType(Step, 'Step', BaseElement.$);
    return Step;
}(BaseElement));
export { Step };

==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/Step.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, markType } from "igniteui-react-core";
import { StepType_$type } from "./StepType";
import { StepDirection_$type } from "./StepDirection";
/**
 * @hidden
 */
var Step = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Step, _super);
    function Step() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.h = null;
        return _this;
    }
    Object.defineProperty(Step.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "nativeElement", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.a.o = this.h;
        },
        enumerable: false,
        configurable: true
    });
    Step.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Step.prototype, "f", {
        get: function () {
            var ret_ = this.b.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "c", {
        get: function () {
            var ret_ = this.b.n("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "g", {
        get: function () {
            var ret_ = this.b.n("optional");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("optional", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "e", {
        get: function () {
            var ret_ = this.b.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Step.prototype, "d", {
        get: function () {
            var ret_ = this.b.n("complete");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("complete", value_);
        },
        enumerable: false,
        configurable: true
    });
    Step.prototype.j = function () {
        this.nativeElement.firstUpdated();
    };
    Step.prototype.l = function (a, b) {
        this.nativeElement.toggleAnimation(this.b.i(enumGetBox(StepType_$type, a)), this.b.i(enumGetBox(StepDirection_$type, b)));
    };
    Step.$t = markType(Step, 'Step', BaseElement.$);
    return Step;
}(BaseElement));
export { Step };
